/***************************************************************************
 *   Copyright (C) 2004 by Fred Schaettgen                                 *
 *   kde.sch@ttgen.net                                                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 ***************************************************************************/

#include <klocale.h>
#include <kdebug.h>
#include <kcombobox.h>
#include "styleclockwidget/prefs.h"
#include "styleconfigdlg.h"
#include "style.h"
#include "styleclockwidget/clockpaintview.h"

StyleConfigDialog::StyleConfigDialog(QWidget *parent, Prefs *prefs, ClockPaintView* clock) :
    KConfigDialog(parent, "stylecfgdlg", prefs, KDialogBase::Swallow,
        KDialogBase::Default | KDialogBase::Ok | KDialogBase::Apply | KDialogBase::Cancel,
        KDialogBase::Ok, false),
        prefs(prefs),
        clock(clock)
{
    styleWidget = new StyleConfigWidget(this);
    addPage(styleWidget, i18n("Themed clock"), QString::fromLatin1("style_settings"));
    styleWidget->show();
    QStringList themes = clock->getAvailableThemes();
    int currentTheme = 0;
    for (int n=0; n<themes.size(); ++n) {
        styleWidget->theme->insertItem(themes[n]);
        if (prefs->theme() == themes[n]) currentTheme = styleWidget->theme->count()-1;
    }
    styleWidget->theme->setCurrentItem(currentTheme);
    connect(styleWidget->theme, SIGNAL(activated(const QString&)), 
        this, SLOT(slotThemeActivated(const QString&)));
}

void StyleConfigDialog::slotThemeActivated(const QString& themeName)
{
    //prefs->setTheme(themeName);    
    kdDebug() << "updateButtons" << endl;
    updateButtons();
}

void StyleConfigDialog::updateSettings()
{
    KConfigDialog::updateSettings();
    if (prefs->theme() != styleWidget->theme->currentText()) {
        prefs->setTheme(styleWidget->theme->currentText());
        kdDebug() << "Updated theme to " << prefs->theme() << endl;
        emit settingsChanged();
        prefs->writeConfig();
    }
}

bool StyleConfigDialog::hasChanged()
{
    bool themeChanged = (prefs->theme() != styleWidget->theme->currentText());
    bool ret = KConfigDialog::hasChanged() || themeChanged;
    kdDebug() << QString("hasChanged %1 vs. %2").arg(prefs->theme())
        .arg(styleWidget->theme->currentText()) << " " << ret << endl;
    return ret;
}

StyleConfigDialog::~StyleConfigDialog()
{
}

#include "styleconfigdlg.moc"
